Learn R Programming

mulgar (version 1.0.5)

pisa: PISA scores

Description

This is data from the 2018 testing, available from https://webfs.oecd.org/pisa2018/SPSS_STU_QQQ.zip. A subset of the data containing samples from Australia and Indonesia, and the simulated scores for math, reading and science.

Arguments

Format

A data set with 10548 rows and 31 columns

Details

CNT

Country (Australia, Indonesia)

PV1MATH-PV10SCIE

simulated scores for math, reading and science

Examples

Run this code

require(dplyr)
data(pisa)
pisa |> count(CNT)

Run the code above in your browser using DataLab