powered by
Generate slice display
ggslice_projection(data, h, proj, center = NULL, col = NULL)
ggplot2 object showing the sliced data
data frame containing only variables used for the display
slice thickness
projection matrix from p to 2 dimensions
center point vector used for anchoring the slice, if NULL the mean of the data is used
grouping vector mapped to color in the display
ggslice
d <- geozoo::sphere.hollow(4, 1000)$points ggslice_projection(d, 0.3, tourr::basis_random(4)) ggslice_projection(d, 0.3, tourr::basis_random(4), center = c(0.4, 0.4, 0.4, 0.4))
Run the code above in your browser using DataLab