powered by
This is data from the 2018 testing, available from https://webfs.oecd.org/pisa2018/SPSS_STU_QQQ.zip. A subset of the data containing samples from Australia and Indonesia, and the simulated scores for math, reading and science.
A data set with 10548 rows and 31 columns
Country (Australia, Indonesia)
simulated scores for math, reading and science
require(dplyr) data(pisa) pisa |> count(CNT)
Run the code above in your browser using DataLab