powered by
This function computes the group variance-covariance matrices, and produces a weighted average. It is useful for examining the linear discriminant analysis model.
pooled_vc(x, cl, prior = rep(1/length(unique(cl)), length(unique(cl))))
matrix
multivariate data set, matrix.
class variable
prior probability for each class, must sum to 1, default all equal
data(clusters) pooled_vc(clusters[,1:5], clusters$cl)
Run the code above in your browser using DataLab